import { Component, HostBinding, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { setTheme } from 'ngx-bootstrap/utils';
import { BaseUIComponent, ContainerProperties, propDescription, LabeledComponent, LabelProperties, PropertyCategories, JSONUtils, StyleProperties, getItemByIndex, BindingProperties, CoreService, CoreModule } from '@ngx-dynamic-components/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { NgSelectModule } from '@ng-select/ng-select';
import { __awaiter, __decorate, __metadata } from 'tslib';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/constants.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const packageName = 'bootstrap';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/container/container.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContainerComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.isContainer = true;
        this.isFluidContainer = false;
        this.height = 'auto';
        this.dropContainer = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const _super = Object.create(null, {
            ngOnInit: { get: () => super.ngOnInit }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.ngOnInit.call(this);
            if (this.properties.fullWidth) {
                this.isFluidContainer = true;
                this.isContainer = false;
            }
            if (this.properties.height) {
                this.height = this.properties.height;
            }
        });
    }
}
ContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-container',
                template: `
    <dc-container-row *ngFor="let item of uiModel.children" [ngStyle]="getStyles(item.itemProperties)"
      (changedDataModel)="changedDataModel.emit($event)"
      [uiModel]='item'
      [dataModel]='dataModel'
      [interpreter]='interpreter'
      [scripts]='scripts'
    ></dc-container-row>
  `,
                styles: [`
    :host {
      display: block;
    }
  `]
            }] }
];
ContainerComponent.propDecorators = {
    isContainer: [{ type: HostBinding, args: ['class.container',] }],
    isFluidContainer: [{ type: HostBinding, args: ['class.container-fluid',] }],
    height: [{ type: HostBinding, args: ['style.height',] }],
    dropContainer: [{ type: HostBinding, args: ['attr.drop-container',] }]
};
if (false) {
    /** @type {?} */
    ContainerComponent.prototype.isContainer;
    /** @type {?} */
    ContainerComponent.prototype.isFluidContainer;
    /** @type {?} */
    ContainerComponent.prototype.height;
    /** @type {?} */
    ContainerComponent.prototype.dropContainer;
}
class BSContainerProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Is full width container, default false',
        example: 'true',
    }),
    __metadata("design:type", Boolean)
], BSContainerProperties.prototype, "fullWidth", void 0);
if (false) {
    /** @type {?} */
    BSContainerProperties.prototype.fullWidth;
}
/** @type {?} */
const example = {
    title: 'Bootstrap container example',
    uiModel: {
        type: 'bootstrap:container',
        containerProperties: {},
        itemProperties: {},
        children: [{
                type: 'bootstrap:bs-row',
                children: [{
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-1',
                            placeholder: 'Name first section',
                            dataModelPath: '$.first'
                        }
                    }, {
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-2',
                            placeholder: 'Name second section',
                            dataModelPath: '$.second'
                        }
                    }]
            }, {
                type: 'bootstrap:bs-row',
                children: [{
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-11',
                            placeholder: 'Name third section',
                            dataModelPath: '$.third'
                        }
                    }, {
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-22',
                            placeholder: 'Name fourth section',
                            dataModelPath: '$.forth'
                        }
                    }]
            }]
    },
    dataModel: {}
};
/**
 * @record
 */
function ContainerComponentConstrutor() { }
/**
 * @record
 */
function ContainerPropertiesConstrutor() { }
/** @type {?} */
const containerDescriptor = {
    name: 'container',
    label: 'Container',
    packageName,
    category: "Containers" /* Containers */,
    description: 'Bootstrap container',
    itemProperties: BSContainerProperties,
    component: ContainerComponent,
    example,
    defaultModel: {
        type: 'bootstrap:container',
        containerProperties: {
            height: '100%',
            width: '100%'
        },
        itemProperties: {},
        children: []
    }
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/container-row/container-row.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContainerRowComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.isRow = true;
        this.isColumn = false;
        this.dropContainer = true;
        this.display = 'flex';
        this.height = 'auto';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const _super = Object.create(null, {
            ngOnInit: { get: () => super.ngOnInit }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.ngOnInit.call(this);
            this.isColumn = this.properties && this.properties.direction === 'column';
            if (this.uiModel.containerProperties && this.uiModel.containerProperties.height) {
                this.height = this.uiModel.containerProperties.height;
            }
        });
    }
}
ContainerRowComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-container-row',
                template: `
    <div *ngFor="let item of uiModel.children" class="col" [ngStyle]="getStyles(item.containerProperties)"
      [ngClass]="item.containerProperties?.bsClasses">
      <dc-ui-selector
          (changedDataModel)="changedDataModel.emit($event)"
          [uiModel]='item'
          [dataModel]='dataModel'
          [interpreter]='interpreter'
          [scripts]='scripts'
      ></dc-ui-selector>
    </div>
  `
            }] }
];
ContainerRowComponent.propDecorators = {
    isRow: [{ type: HostBinding, args: ['class.row',] }],
    isColumn: [{ type: HostBinding, args: ['class.flex-column',] }],
    dropContainer: [{ type: HostBinding, args: ['attr.drop-container',] }],
    display: [{ type: HostBinding, args: ['style.display',] }],
    height: [{ type: HostBinding, args: ['style.height',] }]
};
if (false) {
    /** @type {?} */
    ContainerRowComponent.prototype.isRow;
    /** @type {?} */
    ContainerRowComponent.prototype.isColumn;
    /** @type {?} */
    ContainerRowComponent.prototype.dropContainer;
    /** @type {?} */
    ContainerRowComponent.prototype.display;
    /** @type {?} */
    ContainerRowComponent.prototype.height;
}
class BSContainerRowProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Bootstrap row child classes',
        example: 'col-9'
    }),
    __metadata("design:type", Array)
], BSContainerRowProperties.prototype, "bsClasses", void 0);
__decorate([
    propDescription({
        description: 'Flex direction',
        example: 'column'
    }),
    __metadata("design:type", String)
], BSContainerRowProperties.prototype, "direction", void 0);
if (false) {
    /** @type {?} */
    BSContainerRowProperties.prototype.bsClasses;
    /** @type {?} */
    BSContainerRowProperties.prototype.direction;
}
/** @type {?} */
const example$1 = {
    title: 'Bootstrap container row example',
    uiModel: {
        type: 'bootstrap:bs-row',
        containerProperties: {},
        itemProperties: {
            width: '50%',
            padding: '10px'
        },
        children: [{
                type: 'bootstrap:text-input',
                containerProperties: {},
                itemProperties: {
                    label: 'Input-1',
                    placeholder: 'Name first section',
                    dataModelPath: '$.first'
                }
            }, {
                type: 'bootstrap:text-input',
                containerProperties: {},
                itemProperties: {
                    label: 'Input2',
                    placeholder: 'Name second section',
                    dataModelPath: '$.second'
                }
            }]
    },
    dataModel: {}
};
/**
 * @record
 */
function ContainerRowComponentConstrutor() { }
/**
 * @record
 */
function ContainerPropertiesConstrutor$1() { }
/** @type {?} */
const containerRowDescriptor = {
    name: 'bs-row',
    label: 'Row',
    packageName: 'bootstrap',
    category: "Containers" /* Containers */,
    description: 'Bootstrap row container',
    itemProperties: BSContainerRowProperties,
    component: ContainerRowComponent,
    example: example$1,
    defaultModel: {
        type: 'bootstrap:bs-row',
        containerProperties: {},
        itemProperties: {
            height: '100px',
            width: '100%'
        },
        children: []
    }
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/input-ui/input-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputUIComponent extends LabeledComponent {
    /**
     * @return {?}
     */
    get cssClasses() {
        return {
            invisible: this.properties.visible === false,
            required: this.properties.required
        };
    }
    /**
     * @return {?}
     */
    get inputStyles() {
        return this.getStyles(this.uiModel.itemProperties, ['background', 'color']);
    }
    /**
     * @return {?}
     */
    get wrapperStyles() {
        if (this.properties.inputHeight) {
            return {
                height: this.properties.inputHeight
            };
        }
        return null;
    }
    /**
     * @return {?}
     */
    get name() {
        return this.properties.dataModelPath.replace(/[^A-Z]+/gi, '');
    }
}
InputUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-input-ui',
                template: `
  <div class="form-group align-items-baseline" [fxLayout]="layout" [ngClass]="cssClasses" [ngStyle]="itemStyles">
    <label class="mr-1 {{properties.labelPosition}}" [for]="id" *ngIf="hasLabel"
      [fxFlex]="layout === 'row' ? properties.labelWidth : false">{{properties.label}}</label>
    <div class="w-100 flex-column" [ngStyle]="wrapperStyles">
      <input [attr.id]="id" #inputField="ngModel" [type]="properties.type" class="form-control" [ngStyle]="inputStyles"
        [fxFlex]="properties.inputWidth"
        [placeholder]="properties.placeholder"
        [disabled]="properties.enabled === false"
        [required]="properties.required"
        [minlength]="properties.minlength"
        [maxlength]="properties.maxlength"
        [email]="properties.type === 'email'"
        [pattern]="properties.pattern"
        (input)="changedDataModel.emit(this.dataModel)"
        [attr.name]="name"
        [(ngModel)]="componentDataModel">
      <div *ngIf="inputField.invalid && (inputField.dirty || inputField.touched)" class="alert alert-danger py-0 px-1 m-0">
        <div *ngIf="inputField.errors.required">Field is required.</div>
        <div *ngIf="inputField.errors.minlength">Min length {{properties.minlength}} characters.</div>
        <div *ngIf="inputField.errors.maxlength">Max length {{properties.minlength}} characters.</div>
        <div *ngIf="inputField.errors.email">Email is invalid.</div>
        <div *ngIf="inputField.errors.pattern">Field should match required pattern.</div>
      </div>
    </div>
  </div>
  `,
                styles: ["label.bottom,label.right{order:1}", `
    :host {
      display: inline-block;
    }

    .required label:after {
      content: '*';
    }
  `]
            }] }
];
class InputProperties extends LabelProperties {
}
__decorate([
    propDescription({
        description: 'Text shown when field is empty',
        example: 'Type your name',
    }),
    __metadata("design:type", String)
], InputProperties.prototype, "placeholder", void 0);
__decorate([
    propDescription({
        description: 'Input type',
        example: 'text',
    }),
    __metadata("design:type", String)
], InputProperties.prototype, "type", void 0);
__decorate([
    propDescription({
        description: 'Is enabled',
        example: 'true',
    }),
    __metadata("design:type", Boolean)
], InputProperties.prototype, "enabled", void 0);
__decorate([
    propDescription({
        description: 'Is visible',
        example: 'true',
    }),
    __metadata("design:type", Boolean)
], InputProperties.prototype, "visible", void 0);
__decorate([
    propDescription({
        description: 'Input width',
        example: '200px',
    }),
    __metadata("design:type", String)
], InputProperties.prototype, "inputWidth", void 0);
__decorate([
    propDescription({
        description: 'Is field required',
        example: 'true'
    }),
    __metadata("design:type", String)
], InputProperties.prototype, "inputHeight", void 0);
__decorate([
    propDescription({
        description: 'Is field required',
        example: 'true'
    }),
    __metadata("design:type", Boolean)
], InputProperties.prototype, "required", void 0);
__decorate([
    propDescription({
        description: 'Min field value length',
        example: '5'
    }),
    __metadata("design:type", Number)
], InputProperties.prototype, "minlength", void 0);
__decorate([
    propDescription({
        description: 'Max field value length',
        example: '10'
    }),
    __metadata("design:type", Number)
], InputProperties.prototype, "maxlength", void 0);
__decorate([
    propDescription({
        description: 'RegExp pattern',
        example: '[a-zA-Z ]*'
    }),
    __metadata("design:type", String)
], InputProperties.prototype, "pattern", void 0);
if (false) {
    /** @type {?} */
    InputProperties.prototype.placeholder;
    /** @type {?} */
    InputProperties.prototype.type;
    /** @type {?} */
    InputProperties.prototype.enabled;
    /** @type {?} */
    InputProperties.prototype.visible;
    /** @type {?} */
    InputProperties.prototype.inputWidth;
    /** @type {?} */
    InputProperties.prototype.inputHeight;
    /** @type {?} */
    InputProperties.prototype.required;
    /** @type {?} */
    InputProperties.prototype.minlength;
    /** @type {?} */
    InputProperties.prototype.maxlength;
    /** @type {?} */
    InputProperties.prototype.pattern;
}
/** @type {?} */
const example$2 = {
    title: 'Text input example',
    uiModel: {
        type: `${packageName}:text-input`,
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            placeholder: 'Enter your name',
            dataModelPath: '$.name'
        }
    },
    dataModel: {}
};
/**
 * @record
 */
function InputUIComponentConstrutor() { }
/**
 * @record
 */
function InputPropertiesConstrutor() { }
/** @type {?} */
const inputDescriptor = {
    name: 'text-input',
    label: 'Input field',
    packageName,
    category: "Basic" /* Basic */,
    description: 'Input component',
    itemProperties: InputProperties,
    component: InputUIComponent,
    example: example$2,
    defaultModel: {
        type: `${packageName}:text-input`,
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            placeholder: 'Enter your text',
            dataModelPath: '$.path',
            visible: true,
            enabled: true,
            inputWidth: '100%',
            labelWidth: '80px',
            width: '200px',
            margin: '0',
            type: 'text',
            labelPosition: ''
        }
    },
    propertiesDescriptor: [
        ['type', { name: 'type', label: 'Data Type', category: PropertyCategories.Main,
                combo: [['text', 'number', 'email', 'file', 'url', 'date', 'time', 'datetime-local']]
            }],
        ['inputWidth', { name: 'inputWidth', label: 'Input Width', category: PropertyCategories.Layout }],
        ['inputHeight', { name: 'inputHeight', label: 'Input Height', category: PropertyCategories.Layout }],
        ['enabled', { name: 'enabled', label: 'Enabled', category: PropertyCategories.Main,
                combo: [[{ label: 'Enable', value: true }, { label: 'Disable', value: false }]]
            }],
        ['visible', { name: 'visible', label: 'Visible', category: PropertyCategories.Main,
                combo: [[{ label: 'Visible', value: true }, { label: 'Hidden', value: false }]]
            }]
    ]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/select-ui/select-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectUIComponent extends LabeledComponent {
    constructor() {
        super(...arguments);
        this.options = [];
    }
    /**
     * @return {?}
     */
    onSelect() {
        this.changedDataModel.emit(this.dataModel);
        this.triggerAction('_selectionChanged');
    }
    /**
     * @return {?}
     */
    get selectStyles() {
        if (this.properties.selectHeight) {
            return {
                height: this.properties.selectHeight
            };
        }
        return null;
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.dataModel) {
            /** @type {?} */
            const options = this.properties.options;
            if (Array.isArray(options)) {
                this.options = options;
            }
            else if (typeof options === 'string') {
                /** @type {?} */
                const val = JSONUtils.find(this.dataModel, options);
                if (val !== this.options) {
                    this.options = val;
                }
            }
        }
    }
    /**
     * @return {?}
     */
    get disabled() {
        /** @type {?} */
        const options = this.properties.options;
        return options && options.length ? null : 'disabled';
    }
}
SelectUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-select-ui',
                template: `
    <div class="form-group mb-0" [fxLayout]="layout" [ngStyle]="itemStyles">
      <label selected *ngIf="hasLabel" [for]="id" [class]="properties.labelPosition"
      [fxFlex]="layout === 'row' ? properties.labelWidth : false">{{properties.label}}</label>
      <ng-select [items]="options" (change)="onSelect()" [ngStyle]="selectStyles"
      [(ngModel)]="componentDataModel" bindValue="value" [attr.disabled]="disabled"></ng-select>
    </div>`,
                styles: ["label.bottom,label.right{order:1}", `
    :host ::ng-deep .ng-select.ng-select-single .ng-select-container {
      height: inherit;
      min-height: 30px;
    }
  `]
            }] }
];
if (false) {
    /** @type {?} */
    SelectUIComponent.prototype.options;
}
class SelectProperties extends LabelProperties {
}
__decorate([
    propDescription({
        description: 'Select options.',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Array)
], SelectProperties.prototype, "options", void 0);
__decorate([
    propDescription({
        description: 'Select height.',
        example: '30px',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "selectHeight", void 0);
if (false) {
    /** @type {?} */
    SelectProperties.prototype.options;
    /** @type {?} */
    SelectProperties.prototype.selectHeight;
}
/**
 * @record
 */
function SelectUIComponentConstrutor() { }
/**
 * @record
 */
function SelectPropertiesConstrutor() { }
/** @type {?} */
const example$3 = {
    uiModel: {
        type: `${packageName}:select`,
        containerProperties: {},
        id: 'stateSelection',
        itemProperties: {
            options: [
                { label: 'United Kingdom', value: 'uk' },
                { label: 'Ukraine', value: 'ua' }
            ],
            label: 'Country',
            dataModelPath: '$.country'
        }
    },
    dataModel: {},
    title: 'Basic select example'
};
/** @type {?} */
const selectDescriptor = {
    name: 'select',
    label: 'UI Select Input',
    packageName,
    category: "Basic" /* Basic */,
    description: 'Select component',
    itemProperties: SelectProperties,
    component: SelectUIComponent,
    example: example$3,
    defaultModel: {
        type: `${packageName}:select`,
        containerProperties: {},
        itemProperties: {
            options: [
                { label: 'First option', value: '1' },
                { label: 'Second option', value: '2' }
            ],
            width: '200px',
            label: 'Select option',
            dataModelPath: '$.option'
        }
    },
    propertiesDescriptor: [
        ['selectHeight', { name: 'selectHeight', label: 'Select Height', category: PropertyCategories.Layout }],
    ]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/checkbox-ui/checkbox-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxUIComponent extends LabeledComponent {
    /**
     * @return {?}
     */
    get align() {
        return this.layout === 'row' ? 'start center' : 'center start';
    }
}
CheckboxUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-checkbox-ui',
                template: `
    <div [fxLayout]="layout" [fxLayoutAlign]="align" [ngStyle]="itemStyles">
      <label *ngIf="hasLabel" [for]="id"  class="{{properties.labelPosition}} my-0"
      [fxFlex]="layout === 'row' ? properties.labelWidth : false">{{properties.label}}</label>
      <input type="checkbox" class="mx-0" [attr.id]="id"
        (change)="changedDataModel.emit(this.dataModel)"
        [(ngModel)]="componentDataModel">
    </div>
  `,
                styles: ["label.bottom,label.right{order:1}", `
    label.bottom, label.top {
      margin: 0;
    }

    label.right {
      margin-left: 5px;
    }

    label.left {
      margin-right: 5px;
    }
  `]
            }] }
];
class CheckboxProperties extends LabelProperties {
}
/** @type {?} */
const example$4 = {
    title: 'Checkbox example',
    uiModel: {
        type: `${packageName}:checkbox`,
        containerProperties: {},
        itemProperties: {
            label: 'Accept conditions',
            dataModelPath: '$.accept',
            labelPosition: 'right'
        }
    },
    dataModel: {}
};
/**
 * @record
 */
function CheckboxUIComponentConstrutor() { }
/**
 * @record
 */
function CheckboxPropertiesConstrutor() { }
/** @type {?} */
const checkboxDescriptor = {
    name: 'checkbox',
    packageName,
    label: 'Checkbox',
    category: "Basic" /* Basic */,
    description: 'Checkbox component',
    itemProperties: CheckboxProperties,
    component: CheckboxUIComponent,
    example: example$4,
    defaultModel: {
        type: `${packageName}:checkbox`,
        containerProperties: {},
        itemProperties: {
            label: 'Accept conditions',
            width: '200px',
            dataModelPath: '$.accept',
            labelPosition: 'left'
        }
    }
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/radio-group-ui/radio-group-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RadioGroupUIComponent extends LabeledComponent {
    /**
     * @return {?}
     */
    get align() {
        return this.layout === 'row' ? 'start center' : 'center start';
    }
    /**
     * @param {?} option
     * @return {?}
     */
    onChange(option) {
        this.componentDataModel = option.value;
        this.changedDataModel.emit(this.dataModel);
    }
}
RadioGroupUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-radio-group-ui',
                template: `
    <div class="form-check" *ngFor="let option of properties.options"
      [fxLayout]="layout" [fxLayoutAlign]="align" [ngStyle]="itemStyles">
      <label class="mb-0 {{properties.labelPosition}}" [for]="id" *ngIf="hasLabel"
        [fxFlex]="layout === 'row' ? properties.labelWidth : false">{{option.label}}</label>
      <input type="radio"
        (change)="onChange(option)"
        [name]="properties.dataModelPath" [value]="option.value">
    </div>
  `,
                styles: ["label.bottom,label.right{order:1}"]
            }] }
];
class RadioGroupProperties extends LabelProperties {
}
__decorate([
    propDescription({
        description: 'Radio group options',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Array)
], RadioGroupProperties.prototype, "options", void 0);
if (false) {
    /** @type {?} */
    RadioGroupProperties.prototype.options;
}
/** @type {?} */
const example$5 = {
    title: 'Radio group example',
    uiModel: {
        type: `${packageName}:radio-group`,
        containerProperties: {},
        itemProperties: {
            label: 'Select color',
            dataModelPath: '$.color',
            options: [{ label: 'White', value: 'white' }, { label: 'Black', value: 'black' }],
        }
    },
    dataModel: {}
};
/**
 * @record
 */
function RadioGroupUIComponentConstrutor() { }
/**
 * @record
 */
function RadioGroupPropertiesConstrutor() { }
/** @type {?} */
const radioGroupDescriptor = {
    name: 'radio-group',
    label: 'Single choice boxes',
    packageName,
    category: "Basic" /* Basic */,
    description: 'Radio group component',
    itemProperties: RadioGroupProperties,
    component: RadioGroupUIComponent,
    example: example$5,
    defaultModel: {
        type: `${packageName}:radio-group`,
        containerProperties: {},
        itemProperties: {
            label: 'Select option',
            dataModelPath: '$.radioGroup',
            options: [{ label: 'Option 1', value: '1' }, { label: 'Option 2', value: 'black' }],
        }
    }
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/textarea-ui/textarea-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TextareaUIComponent extends LabeledComponent {
}
TextareaUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-textarea-ui',
                template: `
    <div class="form-group" [ngStyle]="itemStyles"  [fxLayout]="layout">
      <label *ngIf="hasLabel" [class]="properties.labelPosition" [for]="id"
        [fxFlex]="layout === 'row' ? properties.labelWidth : false">{{properties.label}}</label>
      <div class="w-100 flex-column">
        <textarea #txtAreaField="ngModel" [attr.id]="id" class="form-control"
          [rows]="properties.rows"
          [placeholder]="properties.placeholder"
          [ngStyle]="itemStyles"
          [required]="properties.required"
          [minlength]="properties.minlength"
          [maxlength]="properties.maxlength"
          (input)="changedDataModel.emit(this.dataModel)"
          [(ngModel)]="componentDataModel"></textarea>
        <div *ngIf="txtAreaField.invalid && (txtAreaField.dirty || txtAreaField.touched)" class="alert alert-danger py-0 px-1 m-0">
          <div *ngIf="txtAreaField.errors.required">Field is required.</div>
          <div *ngIf="txtAreaField.errors.minlength">Min length {{properties.minlength}} characters.</div>
          <div *ngIf="txtAreaField.errors.maxlength">Max length {{properties.minlength}} characters.</div>
        </div>
      </div>
    </div>
  `,
                styles: ["label.bottom,label.right{order:1}"]
            }] }
];
class TextareaProperties extends LabelProperties {
}
__decorate([
    propDescription({
        description: 'Number of rows in textarea',
        example: '5',
    }),
    __metadata("design:type", Number)
], TextareaProperties.prototype, "rows", void 0);
__decorate([
    propDescription({
        description: 'Text shown when field is empty',
        example: 'Type about yourself',
    }),
    __metadata("design:type", String)
], TextareaProperties.prototype, "placeholder", void 0);
__decorate([
    propDescription({
        description: 'Is field required',
        example: 'true'
    }),
    __metadata("design:type", Boolean)
], TextareaProperties.prototype, "required", void 0);
__decorate([
    propDescription({
        description: 'Min field value length',
        example: '5'
    }),
    __metadata("design:type", Number)
], TextareaProperties.prototype, "minlength", void 0);
__decorate([
    propDescription({
        description: 'Max field value length',
        example: '10'
    }),
    __metadata("design:type", Number)
], TextareaProperties.prototype, "maxlength", void 0);
if (false) {
    /** @type {?} */
    TextareaProperties.prototype.rows;
    /** @type {?} */
    TextareaProperties.prototype.placeholder;
    /** @type {?} */
    TextareaProperties.prototype.required;
    /** @type {?} */
    TextareaProperties.prototype.minlength;
    /** @type {?} */
    TextareaProperties.prototype.maxlength;
}
/** @type {?} */
const example$6 = {
    title: 'Text area example',
    uiModel: {
        type: `${packageName}:textarea`,
        containerProperties: {},
        itemProperties: {
            rows: 10,
            placeholder: 'Type information about yourself',
            dataModelPath: '$.info'
        }
    },
    dataModel: {}
};
/**
 * @record
 */
function TextareaUIComponentConstrutor() { }
/**
 * @record
 */
function TextareaPropertiesConstrutor() { }
/** @type {?} */
const textareaDescriptor = {
    name: 'textarea',
    label: 'Text Area',
    packageName,
    category: "Basic" /* Basic */,
    description: 'Text area component',
    itemProperties: TextareaProperties,
    component: TextareaUIComponent,
    example: example$6,
    defaultModel: {
        type: `${packageName}:textarea`,
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            rows: 5,
            placeholder: 'Placeholder text',
            dataModelPath: '$.textarea'
        }
    }
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/button-ui/button-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonUIComponent extends BaseUIComponent {
    /**
     * @return {?}
     */
    onClick() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.properties.clickActionKey) {
                this.evaluate.emit(true);
                try {
                    yield this.interpreter.evaluate(this.scripts, { dataModel: this.dataModel, uiModel: this.uiModel }, this.properties.clickActionKey);
                    this.changedDataModel.emit(this.dataModel);
                }
                finally {
                    this.evaluate.emit(false);
                }
            }
        });
    }
    /**
     * @return {?}
     */
    get btnClass() {
        return {
            [`btn ${this.properties.btnClass}`]: this.properties.btnClass
        };
    }
}
ButtonUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-button-ui',
                template: `
    <a *ngIf="properties.type == 'link' else btn"
      [ngClass]="btnClass" [ngStyle]="itemStyles" [href]="properties.href">{{properties.label}}</a>
    <ng-template #btn>
      <button [ngClass]="btnClass"
        [type]="properties.type" [ngStyle]="itemStyles"
        (click)="onClick()">{{properties.label}}</button>
    </ng-template>
  `
            }] }
];
class ButtonProperties extends StyleProperties {
}
__decorate([
    propDescription({
        description: 'Button label',
        example: 'Click me!',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "label", void 0);
__decorate([
    propDescription({
        description: 'Key for action that fires onclick',
        example: 'submit',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "clickActionKey", void 0);
__decorate([
    propDescription({
        description: 'Bootstrap predefined button class',
        example: 'btn-secondary',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "btnClass", void 0);
__decorate([
    propDescription({
        description: 'Button type: button|submit|reset|link. Default: button',
        example: 'submit',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "type", void 0);
__decorate([
    propDescription({
        description: 'Link href used in case of type=link.',
        example: 'submit',
    }),
    __metadata("design:type", String)
], ButtonProperties.prototype, "href", void 0);
if (false) {
    /** @type {?} */
    ButtonProperties.prototype.label;
    /** @type {?} */
    ButtonProperties.prototype.clickActionKey;
    /** @type {?} */
    ButtonProperties.prototype.btnClass;
    /** @type {?} */
    ButtonProperties.prototype.type;
    /** @type {?} */
    ButtonProperties.prototype.href;
}
/** @type {?} */
const example$7 = {
    title: 'Basic button example',
    uiModel: {
        type: `${packageName}:button`,
        containerProperties: {},
        itemProperties: {
            label: 'SUBMIT',
            width: '50%',
            margin: '15px',
            padding: '10px 5px 10px 0px',
            clickActionKey: 'consoleLog',
            type: 'button'
        }
    },
    dataModel: {}
};
/**
 * @record
 */
function ButtonUIComponentConstrutor() { }
/**
 * @record
 */
function ButtonPropertiesConstrutor() { }
/** @type {?} */
const buttonDescriptor = {
    name: 'button',
    label: 'Button',
    packageName,
    category: "Basic" /* Basic */,
    description: 'Button component',
    itemProperties: ButtonProperties,
    component: ButtonUIComponent,
    example: example$7,
    defaultModel: {
        type: `${packageName}:button`,
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            clickActionKey: 'consoleLog',
            btnClass: 'btn-primary',
            type: 'button'
        }
    },
    propertiesDescriptor: [
        ['type', { name: 'type', label: 'Type', category: PropertyCategories.Main,
                combo: [['button', 'submit', 'reset']]
            }],
        ['btnClass', { name: 'btnClass', label: 'CSS Class', category: PropertyCategories.Main,
                combo: [['btn-primary', 'btn-secondary', 'btn-light', 'btn-success', 'btn-danger',
                        'btn-warning', 'btn-info', 'btn-dark', 'btn-link']]
            }],
    ]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/card/card.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardComponent extends BaseUIComponent {
    /**
     * @return {?}
     */
    get header() {
        return this.getChildByIndex(0);
    }
    /**
     * @return {?}
     */
    get content() {
        return this.getChildByIndex(1);
    }
    /**
     * @return {?}
     */
    get footer() {
        return this.getChildByIndex(2);
    }
    /**
     * @private
     * @param {?} index
     * @return {?}
     */
    getChildByIndex(index) {
        return getItemByIndex(this.uiModel.children, index);
    }
}
CardComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-card',
                template: `
  <div class="card">
    <div class="card-header" *ngIf="header">
      <dc-ui-selector
        (changedDataModel)="changedDataModel.emit(this.dataModel)"
        [uiModel]='header'
        [dataModel]='dataModel'
        [interpreter]='interpreter'
        [scripts]='scripts'></dc-ui-selector>
    </div>
    <div class="card-body" *ngIf="content">
      <dc-ui-selector
        (changedDataModel)="changedDataModel.emit(this.dataModel)"
        [uiModel]='content'
        [dataModel]='dataModel'
        [interpreter]='interpreter'
        [scripts]='scripts'></dc-ui-selector>
    </div>
    <div class="card-footer" *ngIf="footer">
      <dc-ui-selector
        (changedDataModel)="changedDataModel.emit(this.dataModel)"
        [uiModel]='footer'
        [dataModel]='dataModel'
        [interpreter]='interpreter'
        [scripts]='scripts'></dc-ui-selector>
    </div>
  </div>`
            }] }
];
class CardProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Card can have 3 children, 1 - header, 2 - content, 3 - footer.',
        example: `[null, {
      type: 'material:text',
      containerProperties: {},
      itemProperties: {
        text: 'Card content text',
      }
    }, null]`,
    }),
    __metadata("design:type", Array)
], CardProperties.prototype, "children", void 0);
if (false) {
    /** @type {?} */
    CardProperties.prototype.children;
}
/** @type {?} */
const example$8 = {
    title: 'Card panel example',
    uiModel: {
        type: 'bootstrap:card',
        containerProperties: {},
        itemProperties: {
            padding: '10px',
            margin: '10px auto',
            width: '80%'
        },
        children: [{
                type: 'material:text',
                containerProperties: {},
                itemProperties: {
                    text: 'Card header text',
                    width: '100%'
                }
            }, {
                type: 'material:textarea',
                containerProperties: {
                    width: '100%',
                },
                itemProperties: {
                    rows: 4,
                    placeholder: 'Type card information',
                    dataModelPath: '$.card/info'
                }
            }, {
                type: 'bootstrap:button',
                containerProperties: {},
                itemProperties: {
                    label: 'Submit',
                    margin: '16px',
                    width: '50%',
                    clickActionKey: 'consoleLog'
                }
            }]
    },
    dataModel: {}
};
/**
 * @record
 */
function CardComponentConstrutor() { }
/**
 * @record
 */
function CardPropertiesConstrutor() { }
/** @type {?} */
const cardDescriptor = {
    name: 'card',
    label: 'Card',
    packageName,
    category: "Containers" /* Containers */,
    description: 'Card layout component',
    itemProperties: CardProperties,
    component: CardComponent,
    example: example$8
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/text-ui/text-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TextUIComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.display = 'inline-block';
    }
    /**
     * @return {?}
     */
    get txtStyle() {
        return this.properties['text-style'];
    }
    /**
     * @return {?}
     */
    get text() {
        return this.componentDataModel || this.properties.text;
    }
}
TextUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-ui-text',
                template: `
    <div [ngSwitch]="txtStyle">
      <h1 *ngSwitchCase="'h1'" [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</h1>
      <h2 *ngSwitchCase="'h2'" [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</h2>
      <h3 *ngSwitchCase="'h3'" [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</h3>
      <h4 *ngSwitchCase="'h4'" [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</h4>
      <h5 *ngSwitchCase="'h5'" [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</h5>
      <h6 *ngSwitchCase="'h6'" [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</h6>
      <p *ngSwitchCase="''" [ngStyle]="itemStyles">{{text}}</p>
      <p *ngSwitchCase="undefined" [ngStyle]="itemStyles">{{text}}</p>
      <span *ngSwitchDefault [class]="txtStyle" [ngStyle]="itemStyles">{{text}}</span>
    </div>
    `
            }] }
];
TextUIComponent.propDecorators = {
    display: [{ type: HostBinding, args: ['style.display',] }]
};
if (false) {
    /** @type {?} */
    TextUIComponent.prototype.display;
}
class TextProperties extends BindingProperties {
}
__decorate([
    propDescription({
        description: 'Displays text data.',
        example: 'Text information',
    }),
    __metadata("design:type", String)
], TextProperties.prototype, "text", void 0);
__decorate([
    propDescription({
        description: 'Text style text data.',
        example: 'h2',
    }),
    __metadata("design:type", String)
], TextProperties.prototype, "text-style", void 0);
if (false) {
    /** @type {?} */
    TextProperties.prototype.text;
    /* Skipping unnamed member:
    @propDescription({
        description: 'Text style text data.',
        example: 'h2',
      })
      'text-style'?: string;*/
}
/**
 * @record
 */
function TextUIComponentConstrutor() { }
/**
 * @record
 */
function TextPropertiesConstrutor() { }
/** @type {?} */
const example$9 = {
    title: 'Text compoent example',
    uiModel: {
        type: `${packageName}:text`,
        containerProperties: {},
        itemProperties: {
            text: ``,
            width: '50%',
            padding: '20px'
        }
    },
    dataModel: {}
};
/** @type {?} */
const textDescriptor = {
    name: 'text',
    packageName,
    label: 'Text',
    category: "Basic" /* Basic */,
    description: 'Text component',
    itemProperties: TextProperties,
    component: TextUIComponent,
    example: example$9,
    defaultModel: {
        type: `${packageName}:text`,
        itemProperties: {
            text: 'Text',
            width: '100%'
        },
        containerProperties: {}
    },
    propertiesDescriptor: [
        ['text-style', {
                name: 'text-style', label: 'Text style', category: PropertyCategories.Main,
                combo: [['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'display-1', 'display-2', 'display-3', 'display-4']]
            }]
    ]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/icon-ui/icon-ui.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IconUIComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.display = 'inline-block';
    }
    /**
     * @return {?}
     */
    get iconClass() {
        return this.componentDataModel || this.properties.iconClass;
    }
}
IconUIComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-icon-ui',
                template: `
    <div [ngSwitch]="itemStyles">
      <i [class]="iconClass" [ngStyle]="{fontSize: properties.size || '1rem'}"></i>
    </div>
    `,
                styles: ['./icon-ui.component.sass']
            }] }
];
IconUIComponent.propDecorators = {
    display: [{ type: HostBinding, args: ['style.display',] }]
};
if (false) {
    /** @type {?} */
    IconUIComponent.prototype.display;
}
class IconProperties extends BindingProperties {
}
__decorate([
    propDescription({
        description: 'Icon font awesome class',
        example: 'Text information',
    }),
    __metadata("design:type", String)
], IconProperties.prototype, "iconClass", void 0);
__decorate([
    propDescription({
        description: 'Icon size',
        example: '2rem',
    }),
    __metadata("design:type", String)
], IconProperties.prototype, "size", void 0);
if (false) {
    /** @type {?} */
    IconProperties.prototype.iconClass;
    /** @type {?} */
    IconProperties.prototype.size;
}
/**
 * @record
 */
function IconUIComponentConstrutor() { }
/**
 * @record
 */
function IconPropertiesConstrutor() { }
/** @type {?} */
const example$a = {
    title: 'Icon compoent example',
    uiModel: {
        type: `${packageName}:icon`,
        containerProperties: {},
        itemProperties: {
            iconClass: 'fa fa-play',
            width: '50%',
            padding: '20px'
        }
    },
    dataModel: {}
};
/** @type {?} */
const ICONS = ['fa fa-send', 'fa fa-play', 'fa fa-picture-o', 'fa fa-area-chart', 'fa fa-bank', 'fa fa-beer',
    'fa fa-automobile', 'fa fa-bag', 'fa fa-book', 'fa fa-bell', 'fa fa-camera', 'fa fa-calendar', 'fa fa-user',
    'fa fa-globe', 'fa fa-gift', 'fa fa-group', 'fa fa-gear', 'fa fa-info', 'fa fa-money', 'fa fa-print', 'fa fa-registered',
    'fa fa-share', 'fa fa-shopping-card', 'fa fa-tags', 'fa fa-tasks', 'fa fa-star', 'fa fa-univarsity', 'fa fa-file', 'fa fa-ticket',
    'fa fa-television', 'fa fa-suitcase', 'fa fa-server', 'fa fa-map', 'fa fa-leptop', 'fa fa-home', 'fa fa-hashtag', 'fa fa-clock-o'];
/** @type {?} */
const iconDescriptor = {
    name: 'icon',
    packageName,
    label: 'Icon',
    category: "Basic" /* Basic */,
    description: 'Icon component',
    itemProperties: IconProperties,
    component: IconUIComponent,
    example: example$a,
    defaultModel: {
        type: `${packageName}:icon`,
        itemProperties: {
            iconClass: 'fa fa-play',
            width: '100%'
        },
        containerProperties: {}
    },
    propertiesDescriptor: [
        ['iconClass', {
                name: 'iconClass', label: 'Icon Class', category: PropertyCategories.Main,
                combo: [ICONS]
            }]
    ]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/register.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const COMPONENTS_LIST = [
    containerDescriptor,
    containerRowDescriptor,
    inputDescriptor,
    selectDescriptor,
    checkboxDescriptor,
    radioGroupDescriptor,
    textareaDescriptor,
    buttonDescriptor,
    cardDescriptor,
    textDescriptor,
    iconDescriptor
];
// Register components.
/**
 * @return {?}
 */
function registerComponents() {
    COMPONENTS_LIST.forEach((/**
     * @param {?} component
     * @return {?}
     */
    component => CoreService.registerComponent(component)));
}
/**
 * @return {?}
 */
function getCategories() {
    /** @type {?} */
    const categories = COMPONENTS_LIST.reduce((/**
     * @param {?} map
     * @param {?} desc
     * @return {?}
     */
    (map, desc) => {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }), {});
    return Object.entries(categories).map((/**
     * @param {?} __0
     * @return {?}
     */
    ([key, val]) => {
        return {
            name: key,
            components: val,
            packageName
        };
    }));
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/bootstrap.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BootstrapModule {
    constructor() {
        setTheme('bs4');
        registerComponents();
    }
}
BootstrapModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ContainerComponent, ContainerRowComponent, InputUIComponent, SelectUIComponent,
                    CheckboxUIComponent, RadioGroupUIComponent, TextareaUIComponent, ButtonUIComponent, CardComponent, TextUIComponent, IconUIComponent],
                imports: [
                    CoreModule,
                    CommonModule,
                    FormsModule,
                    FlexLayoutModule,
                    NgSelectModule
                ],
                exports: [ContainerComponent, ContainerRowComponent, InputUIComponent],
                entryComponents: [ContainerComponent, ContainerRowComponent, InputUIComponent, SelectUIComponent, IconUIComponent,
                    CheckboxUIComponent, RadioGroupUIComponent, TextareaUIComponent, ButtonUIComponent, CardComponent, TextUIComponent]
            },] }
];
/** @nocollapse */
BootstrapModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-dynamic-components-bootstrap.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { BootstrapModule, COMPONENTS_LIST, getCategories, ContainerComponent as ɵa, BSContainerProperties as ɵb, example$6 as ɵba, textareaDescriptor as ɵbb, ButtonUIComponent as ɵbc, ButtonProperties as ɵbd, example$7 as ɵbe, buttonDescriptor as ɵbf, CardComponent as ɵbg, CardProperties as ɵbh, cardDescriptor as ɵbi, TextUIComponent as ɵbj, TextProperties as ɵbk, textDescriptor as ɵbl, IconUIComponent as ɵbm, IconProperties as ɵbn, iconDescriptor as ɵbo, packageName as ɵbp, example as ɵc, containerDescriptor as ɵd, ContainerRowComponent as ɵe, BSContainerRowProperties as ɵf, example$1 as ɵg, containerRowDescriptor as ɵh, InputUIComponent as ɵi, InputProperties as ɵj, example$2 as ɵk, inputDescriptor as ɵl, SelectUIComponent as ɵm, SelectProperties as ɵn, example$3 as ɵo, selectDescriptor as ɵp, CheckboxUIComponent as ɵq, CheckboxProperties as ɵr, example$4 as ɵs, checkboxDescriptor as ɵt, RadioGroupUIComponent as ɵu, RadioGroupProperties as ɵv, example$5 as ɵw, radioGroupDescriptor as ɵx, TextareaUIComponent as ɵy, TextareaProperties as ɵz };
//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map
